# ispyb_client
FastAPI Prototype

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1alpha
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ispyb_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ispyb_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import ispyb_client
from pprint import pprint
from ispyb_client.apis.tags import admin_api
from ispyb_client.model.action_type import ActionType
from ispyb_client.model.http_validation_error import HTTPValidationError
from ispyb_client.model.paginated_admin_activity import PaginatedAdminActivity
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = ispyb_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = ispyb_client.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# Enter a context with an instance of the API client
with ispyb_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = admin_api.AdminApi(api_client)
    action_type = ActionType("db_options") # ActionType |  (optional)
skip = 0 # int | Results to skip (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='skip', paramName='skip', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='Results to skip', unescapedDescription='Results to skip', baseType='null', defaultValue='0', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='0', jsonSchema='{
  "name" : "skip",
  "in" : "query",
  "description" : "Results to skip",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "title" : "Skip",
    "minimum" : 0.0,
    "type" : "integer",
    "description" : "Results to skip",
    "default" : 0
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=true, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='0', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='SkipSchema', complexType='null', getter='getSkip', setter='setSkip', description='Results to skip', dataType='int', datatypeWithEnum='int', dataFormat='null', name='skip', min='null', max='null', defaultValue='0', defaultValueWithParam=' = data.skip;', baseType='int', containerType='null', title='Skip', unescapedDescription='Results to skip', maxLength=null, minLength=null, pattern='null', example='0', jsonSchema='{
  "title" : "Skip",
  "minimum" : 0.0,
  "type" : "integer",
  "description" : "Results to skip",
  "default" : 0
}', minimum='0', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=true, isInherited=false, discriminatorValue='null', nameInCamelCase='Skip', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})
limit = 25 # int | Number of results to show (optional) (default to CodegenParameter{isFormParam=false, isQueryParam=true, isPathParam=false, isHeaderParam=false, isCookieParam=false, isBodyParam=false, isContainer=false, isCollectionFormatMulti=false, isPrimitiveType=true, isModel=false, isExplode=true, baseName='limit', paramName='limit', dataType='int', datatypeWithEnum='null', dataFormat='null', collectionFormat='null', description='Number of results to show', unescapedDescription='Number of results to show', baseType='null', defaultValue='25', enumDefaultValue='null', enumName='null', style='FORM', deepObject='false', allowEmptyValue='false', example='25', jsonSchema='{
  "name" : "limit",
  "in" : "query",
  "description" : "Number of results to show",
  "required" : false,
  "style" : "form",
  "explode" : true,
  "schema" : {
    "title" : "Limit",
    "type" : "integer",
    "description" : "Number of results to show",
    "default" : 25
  }
}', isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isAnyType=false, isArray=false, isMap=false, isFile=false, isEnum=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, additionalProperties=null, vars=[], requiredVars=[], vendorExtensions={}, hasValidation=false, maxProperties=null, minProperties=null, isNullable=false, isDeprecated=false, required=false, maximum='null', exclusiveMaximum=false, minimum='null', exclusiveMinimum=false, maxLength=null, minLength=null, pattern='null', maxItems=null, minItems=null, uniqueItems=false, uniqueItemsBoolean=null, contentType=null, multipleOf=null, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, schema=CodegenProperty{openApiType='integer', baseName='LimitSchema', complexType='null', getter='getLimit', setter='setLimit', description='Number of results to show', dataType='int', datatypeWithEnum='int', dataFormat='null', name='limit', min='null', max='null', defaultValue='25', defaultValueWithParam=' = data.limit;', baseType='int', containerType='null', title='Limit', unescapedDescription='Number of results to show', maxLength=null, minLength=null, pattern='null', example='25', jsonSchema='{
  "title" : "Limit",
  "type" : "integer",
  "description" : "Number of results to show",
  "default" : 25
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, required=false, deprecated=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=true, isShort=false, isLong=false, isUnboundedInteger=true, isNumber=false, isFloat=false, isDouble=false, isDecimal=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isArray=false, isMap=false, isEnum=false, isInnerEnum=false, isAnyType=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, isDiscriminator=false, _enum=null, allowableValues=null, items=null, additionalProperties=null, vars=[], requiredVars=[], mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Limit', nameInSnakeCase='null', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, uniqueItemsBoolean=null, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false, isNull=false, getAdditionalPropertiesIsAnyType=false, getHasVars=false, getHasRequired=false, getHasDiscriminatorWithNonEmptyMapping=false, composedSchemas=null, hasMultipleTypes=false, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false, isBooleanSchemaTrue=false, isBooleanSchemaFalse=false, format=null, dependentRequired=null, contains=null}, content=null, requiredVarsMap=null, ref=null, schemaIsFromAdditionalProperties=false})

    try:
        # Get Activity
        api_response = api_instance.get_activity(action_type=action_typeskip=skiplimit=limit)
        pprint(api_response)
    except ispyb_client.ApiException as e:
        print("Exception when calling AdminApi->get_activity: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**get_activity**](docs/apis/tags/AdminApi.md#get_activity) | **get** /ispyb/api/v1/admin/activity | Get Activity
*AuthenticationApi* | [**config_ispyb_api_v1_auth_config_get**](docs/apis/tags/AuthenticationApi.md#config_ispyb_api_v1_auth_config_get) | **get** /ispyb/api/v1/auth/config | Config
*AuthenticationApi* | [**login_ispyb_api_v1_auth_login_post**](docs/apis/tags/AuthenticationApi.md#login_ispyb_api_v1_auth_login_post) | **post** /ispyb/api/v1/auth/login | Login
*CurrentUserApi* | [**current_user**](docs/apis/tags/CurrentUserApi.md#current_user) | **get** /ispyb/api/v1/user/current | Current User
*DataCollectionsApi* | [**get_datacollection_anaylsis_image**](docs/apis/tags/DataCollectionsApi.md#get_datacollection_anaylsis_image) | **get** /ispyb/api/v1/datacollections/images/quality/{dataCollectionId} | Get Datacollection Anaylsis Image
*DataCollectionsApi* | [**get_datacollection_attachment**](docs/apis/tags/DataCollectionsApi.md#get_datacollection_attachment) | **get** /ispyb/api/v1/datacollections/attachments/{dataCollectionFileAttachmentId} | Get Datacollection Attachment
*DataCollectionsApi* | [**get_datacollection_attachments**](docs/apis/tags/DataCollectionsApi.md#get_datacollection_attachments) | **get** /ispyb/api/v1/datacollections/attachments | Get Datacollection Attachments
*DataCollectionsApi* | [**get_datacollection_diffraction_image**](docs/apis/tags/DataCollectionsApi.md#get_datacollection_diffraction_image) | **get** /ispyb/api/v1/datacollections/images/diffraction/{dataCollectionId} | Get Datacollection Diffraction Image
*DataCollectionsApi* | [**get_datacollection_image**](docs/apis/tags/DataCollectionsApi.md#get_datacollection_image) | **get** /ispyb/api/v1/datacollections/images/{dataCollectionId} | Get Datacollection Image
*DataCollectionsApi* | [**get_per_image_analysis**](docs/apis/tags/DataCollectionsApi.md#get_per_image_analysis) | **get** /ispyb/api/v1/datacollections/quality | Get Per Image Analysis
*DataCollectionsApi* | [**get_workflow_step_attachment**](docs/apis/tags/DataCollectionsApi.md#get_workflow_step_attachment) | **get** /ispyb/api/v1/datacollections/workflows/steps/{workflowStepId} | Get Workflow Step Attachment
*DataCollectionsApi* | [**get_workflow_steps**](docs/apis/tags/DataCollectionsApi.md#get_workflow_steps) | **get** /ispyb/api/v1/datacollections/workflows/steps | Get Workflow Steps
*DataCollectionsLegacyWithHeaderTokenApi* | [**get**](docs/apis/tags/DataCollectionsLegacyWithHeaderTokenApi.md#get) | **get** /ispyb/api/v1/legacy/data_collections/groups/session/{session_id} | Get
*EMLegacyWithHeaderTokenApi* | [**get_classification**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_classification) | **get** /ispyb/api/v1/legacy/em/session/{session_id}/classification | Get Classification
*EMLegacyWithHeaderTokenApi* | [**get_ctf_thumbnail**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_ctf_thumbnail) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/movie/{movie_id}/thumbnail/ctf | Get Ctf Thumbnail
*EMLegacyWithHeaderTokenApi* | [**get_groups_for_session**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_groups_for_session) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/session/{session_id}/data_collections/groups | Get Groups For Session
*EMLegacyWithHeaderTokenApi* | [**get_motion_drift_thumbnail**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_motion_drift_thumbnail) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/movie/{movie_id}/plot/motioncorrectiondrift | Get Motion Drift Thumbnail
*EMLegacyWithHeaderTokenApi* | [**get_motion_thumbnail**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_motion_thumbnail) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/movie/{movie_id}/thumbnail/motioncorrection | Get Motion Thumbnail
*EMLegacyWithHeaderTokenApi* | [**get_movie_thumbnail**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_movie_thumbnail) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/movie/{movie_id}/thumbnail | Get Movie Thumbnail
*EMLegacyWithHeaderTokenApi* | [**get_movies**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_movies) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/datacollection/{datacollection_id}/movies | Get Movies
*EMLegacyWithHeaderTokenApi* | [**get_stats_dcids**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_stats_dcids) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/data_collections/{data_collections_ids}/stats | Get Stats Dcids
*EMLegacyWithHeaderTokenApi* | [**get_stats_group**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_stats_group) | **get** /ispyb/api/v1/legacy/em/proposal/{proposal_id}/data_collections_group/{data_collections_group_id}/stats | Get Stats Group
*EMLegacyWithHeaderTokenApi* | [**get_stats_session**](docs/apis/tags/EMLegacyWithHeaderTokenApi.md#get_stats_session) | **get** /ispyb/api/v1/legacy/em/session/{session_id}/stats | Get Stats Session
*EventChainsApi* | [**get_ssx_datacollection_eventchains**](docs/apis/tags/EventChainsApi.md#get_ssx_datacollection_eventchains) | **get** /ispyb/api/v1/eventchain | Get Ssx Datacollection Eventchains
*EventsApi* | [**get_event_types**](docs/apis/tags/EventsApi.md#get_event_types) | **get** /ispyb/api/v1/events/types | Get Event Types
*EventsApi* | [**get_events**](docs/apis/tags/EventsApi.md#get_events) | **get** /ispyb/api/v1/events | Get Events
*LabContactsApi* | [**create_lab_contact**](docs/apis/tags/LabContactsApi.md#create_lab_contact) | **post** /ispyb/api/v1/labcontacts | Create Lab Contact
*LabContactsApi* | [**get_lab_contact**](docs/apis/tags/LabContactsApi.md#get_lab_contact) | **get** /ispyb/api/v1/labcontacts/{labContactId} | Get Lab Contact
*LabContactsApi* | [**get_lab_contacts**](docs/apis/tags/LabContactsApi.md#get_lab_contacts) | **get** /ispyb/api/v1/labcontacts | Get Lab Contacts
*LabContactsApi* | [**update_lab_contact**](docs/apis/tags/LabContactsApi.md#update_lab_contact) | **patch** /ispyb/api/v1/labcontacts/{labContactId} | Update Lab Contact
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_classification_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_classification_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/session/{session_id}/classification | Get Classification
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_ctf_thumbnail_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_ctf_thumbnail_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/{datacollection_id}/movie/{movie_id}/ctf/thumbnail | Get Ctf Thumbnail
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_groups_for_session_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_groups_for_session_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/session/{session_id}/list | Get Groups For Session
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/session/{session_id}/list | Get
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_motion_drift_thumbnail_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_motion_drift_thumbnail_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/{datacollection_id}/movie/{movie_id}/motioncorrection/drift | Get Motion Drift Thumbnail
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_motion_thumbnail_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_motion_thumbnail_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/{datacollection_id}/movie/{movie_id}/motioncorrection/thumbnail | Get Motion Thumbnail
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_movie_thumbnail_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_movie_thumbnail_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/{datacollection_id}/movie/{movie_id}/thumbnail | Get Movie Thumbnail
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_movies_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_movies_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/em/datacollection/{datacollection_id}/movie/all | Get Movies
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_proposal_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_proposal_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/info/get | Get Proposal
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_proposals_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_proposals_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/list | Get Proposals
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_sessions_by_dates_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_sessions_by_dates_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/session/date/{start_date}/{end_date}/list | Get Sessions By Dates
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_sessions_for_proposal_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_sessions_for_proposal_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal_id}/session/list | Get Sessions For Proposal
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_sessions_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_sessions_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/session/list | Get Sessions
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_stats_dcids_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_stats_dcids_legacy_token) | **get** /ispyb/api/v1/legacy/proposal/{proposal_id}/data_collections/{data_collections_ids}/stats | Get Stats Dcids
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_stats_group_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_stats_group_legacy_token) | **get** /ispyb/api/v1/legacy/proposal/{proposal_id}/data_collections_group/{data_collections_group_id}/stats | Get Stats Group
*LegacyWithTokenInPathOnlyForCompatibilityApi* | [**get_stats_session_legacy_token**](docs/apis/tags/LegacyWithTokenInPathOnlyForCompatibilityApi.md#get_stats_session_legacy_token) | **get** /ispyb/api/v1/legacy/{token}/proposal/{proposal}/em/session/{session_id}/stats | Get Stats Session
*OptionsApi* | [**get_options**](docs/apis/tags/OptionsApi.md#get_options) | **get** /ispyb/api/v1/options | Get Options
*OptionsApi* | [**get_ui_options**](docs/apis/tags/OptionsApi.md#get_ui_options) | **get** /ispyb/api/v1/options/ui | Get Ui Options
*OptionsApi* | [**update_options**](docs/apis/tags/OptionsApi.md#update_options) | **patch** /ispyb/api/v1/options | Update Options
*ProposalsApi* | [**get_proposal**](docs/apis/tags/ProposalsApi.md#get_proposal) | **get** /ispyb/api/v1/proposals/{proposal} | Get Proposal
*ProposalsApi* | [**get_proposals**](docs/apis/tags/ProposalsApi.md#get_proposals) | **get** /ispyb/api/v1/proposals | Get Proposals
*ProposalsLegacyWithHeaderTokenApi* | [**get_proposal**](docs/apis/tags/ProposalsLegacyWithHeaderTokenApi.md#get_proposal) | **get** /ispyb/api/v1/legacy/proposals/{proposal_id} | Get Proposal
*ProposalsLegacyWithHeaderTokenApi* | [**get_proposals**](docs/apis/tags/ProposalsLegacyWithHeaderTokenApi.md#get_proposals) | **get** /ispyb/api/v1/legacy/proposals | Get Proposals
*ProteinsApi* | [**get_protein**](docs/apis/tags/ProteinsApi.md#get_protein) | **get** /ispyb/api/v1/proteins/{proteinId} | Get Protein
*ProteinsApi* | [**get_proteins**](docs/apis/tags/ProteinsApi.md#get_proteins) | **get** /ispyb/api/v1/proteins | Get Proteins
*SamplesApi* | [**get_sample**](docs/apis/tags/SamplesApi.md#get_sample) | **get** /ispyb/api/v1/samples/{blSampleId} | Get Sample
*SamplesApi* | [**get_sample_image**](docs/apis/tags/SamplesApi.md#get_sample_image) | **get** /ispyb/api/v1/samples/images/{blSampleImageId} | Get Sample Image
*SamplesApi* | [**get_sample_images**](docs/apis/tags/SamplesApi.md#get_sample_images) | **get** /ispyb/api/v1/samples/images | Get Sample Images
*SamplesApi* | [**get_samples**](docs/apis/tags/SamplesApi.md#get_samples) | **get** /ispyb/api/v1/samples | Get Samples
*SamplesApi* | [**get_subsample**](docs/apis/tags/SamplesApi.md#get_subsample) | **get** /ispyb/api/v1/samples/sub/{blSubSampleId} | Get Subsample
*SamplesApi* | [**get_subsamples**](docs/apis/tags/SamplesApi.md#get_subsamples) | **get** /ispyb/api/v1/samples/sub | Get Subsamples
*SerialCrystallographyApi* | [**get_ssx_datacollection_processing_cells**](docs/apis/tags/SerialCrystallographyApi.md#get_ssx_datacollection_processing_cells) | **get** /ispyb/api/v1/ssx/datacollection/processing/cells | Get Ssx Datacollection Processing Cells
*SerialCrystallographyApi* | [**get_ssx_datacollection_processing_cells_histogram**](docs/apis/tags/SerialCrystallographyApi.md#get_ssx_datacollection_processing_cells_histogram) | **get** /ispyb/api/v1/ssx/datacollection/processing/cells/histogram | Get Ssx Datacollection Processing Cells Histogram
*SerialCrystallographyApi* | [**get_ssx_datacollection_processing_stats**](docs/apis/tags/SerialCrystallographyApi.md#get_ssx_datacollection_processing_stats) | **get** /ispyb/api/v1/ssx/datacollection/processing/stats | Get Ssx Datacollection Processing Stats
*SessionApi* | [**get_session**](docs/apis/tags/SessionApi.md#get_session) | **get** /ispyb/api/v1/session/{sessionId} | Get Session
*SessionsApi* | [**get_session**](docs/apis/tags/SessionsApi.md#get_session) | **get** /ispyb/api/v1/sessions/{sessionId} | Get Session
*SessionsApi* | [**get_sessions**](docs/apis/tags/SessionsApi.md#get_sessions) | **get** /ispyb/api/v1/sessions | Get Sessions
*SessionsApi* | [**get_sessions_for_beamline_group**](docs/apis/tags/SessionsApi.md#get_sessions_for_beamline_group) | **get** /ispyb/api/v1/sessions/group | Get Sessions For Beamline Group
*SessionsLegacyWithHeaderTokenApi* | [**get_sessions**](docs/apis/tags/SessionsLegacyWithHeaderTokenApi.md#get_sessions) | **get** /ispyb/api/v1/legacy/sessions | Get Sessions
*SessionsLegacyWithHeaderTokenApi* | [**get_sessions_by_dates**](docs/apis/tags/SessionsLegacyWithHeaderTokenApi.md#get_sessions_by_dates) | **get** /ispyb/api/v1/legacy/sessions/date/{start_date}/{end_date} | Get Sessions By Dates
*SessionsLegacyWithHeaderTokenApi* | [**get_sessions_for_proposal**](docs/apis/tags/SessionsLegacyWithHeaderTokenApi.md#get_sessions_for_proposal) | **get** /ispyb/api/v1/legacy/sessions/proposal/{proposal_id} | Get Sessions For Proposal
*WebservicesSerialCrystallographyApi* | [**create_datacollection**](docs/apis/tags/WebservicesSerialCrystallographyApi.md#create_datacollection) | **post** /ispyb/api/v1/webservices/ssx/datacollection | Create Datacollection
*WebservicesSerialCrystallographyApi* | [**create_datacollectiongroup**](docs/apis/tags/WebservicesSerialCrystallographyApi.md#create_datacollectiongroup) | **post** /ispyb/api/v1/webservices/ssx/datacollectiongroup | Create Datacollectiongroup
*WebservicesSerialCrystallographyApi* | [**create_ssx_datacollection_processing**](docs/apis/tags/WebservicesSerialCrystallographyApi.md#create_ssx_datacollection_processing) | **post** /ispyb/api/v1/webservices/ssx/datacollection/{dataCollectionId}/processing | Create Ssx Datacollection Processing
*WebservicesUserPortalSyncApi* | [**sync_proposal**](docs/apis/tags/WebservicesUserPortalSyncApi.md#sync_proposal) | **post** /ispyb/api/v1/webservices/userportalsync/sync_proposal | Sync Proposal

## Documentation For Models

 - [ActionType](docs/models/ActionType.md)
 - [AdminActivity](docs/models/AdminActivity.md)
 - [AuthConfig](docs/models/AuthConfig.md)
 - [BeamLineGroup](docs/models/BeamLineGroup.md)
 - [BeamLineGroupBeamLine](docs/models/BeamLineGroupBeamLine.md)
 - [BeamLineSetup](docs/models/BeamLineSetup.md)
 - [Component](docs/models/Component.md)
 - [Composition](docs/models/Composition.md)
 - [CurrentUser](docs/models/CurrentUser.md)
 - [DataCollection](docs/models/DataCollection.md)
 - [DataCollectionFileAttachment](docs/models/DataCollectionFileAttachment.md)
 - [DataCollectionFileAttachmentMetaData](docs/models/DataCollectionFileAttachmentMetaData.md)
 - [DataCollectionGroup](docs/models/DataCollectionGroup.md)
 - [DataCollectionMetaData](docs/models/DataCollectionMetaData.md)
 - [Detector](docs/models/Detector.md)
 - [EnergyScan](docs/models/EnergyScan.md)
 - [Event](docs/models/Event.md)
 - [EventChainCreate](docs/models/EventChainCreate.md)
 - [EventChainResponse](docs/models/EventChainResponse.md)
 - [EventCreate](docs/models/EventCreate.md)
 - [EventResponse](docs/models/EventResponse.md)
 - [EventStatus](docs/models/EventStatus.md)
 - [GridInfo](docs/models/GridInfo.md)
 - [HTTPValidationError](docs/models/HTTPValidationError.md)
 - [Histogram](docs/models/Histogram.md)
 - [LabContact](docs/models/LabContact.md)
 - [LabContactCreate](docs/models/LabContactCreate.md)
 - [LabContactCreateOptional](docs/models/LabContactCreateOptional.md)
 - [Laboratory](docs/models/Laboratory.md)
 - [LaboratoryCreate](docs/models/LaboratoryCreate.md)
 - [LaboratoryCreateOptional](docs/models/LaboratoryCreateOptional.md)
 - [Login](docs/models/Login.md)
 - [Message](docs/models/Message.md)
 - [Options](docs/models/Options.md)
 - [Order](docs/models/Order.md)
 - [PaginatedAdminActivity](docs/models/PaginatedAdminActivity.md)
 - [PaginatedDataCollectionFileAttachment](docs/models/PaginatedDataCollectionFileAttachment.md)
 - [PaginatedEvent](docs/models/PaginatedEvent.md)
 - [PaginatedEventType](docs/models/PaginatedEventType.md)
 - [PaginatedLabContact](docs/models/PaginatedLabContact.md)
 - [PaginatedPerImageAnalysis](docs/models/PaginatedPerImageAnalysis.md)
 - [PaginatedProposal](docs/models/PaginatedProposal.md)
 - [PaginatedProtein](docs/models/PaginatedProtein.md)
 - [PaginatedSample](docs/models/PaginatedSample.md)
 - [PaginatedSampleImage](docs/models/PaginatedSampleImage.md)
 - [PaginatedSession](docs/models/PaginatedSession.md)
 - [PaginatedSubSample](docs/models/PaginatedSubSample.md)
 - [PaginatedWorkflowStep](docs/models/PaginatedWorkflowStep.md)
 - [PerImageAnalysis](docs/models/PerImageAnalysis.md)
 - [Person](docs/models/Person.md)
 - [PersonCreate](docs/models/PersonCreate.md)
 - [PersonCreateOptional](docs/models/PersonCreateOptional.md)
 - [PersonProposalLaboratory](docs/models/PersonProposalLaboratory.md)
 - [PersonSessionLaboratory](docs/models/PersonSessionLaboratory.md)
 - [PersonSessionOptions](docs/models/PersonSessionOptions.md)
 - [PluginConfig](docs/models/PluginConfig.md)
 - [Position](docs/models/Position.md)
 - [Proposal](docs/models/Proposal.md)
 - [ProposalMetaData](docs/models/ProposalMetaData.md)
 - [ProposalState](docs/models/ProposalState.md)
 - [Protein](docs/models/Protein.md)
 - [ProteinMetaData](docs/models/ProteinMetaData.md)
 - [ProteinOrder](docs/models/ProteinOrder.md)
 - [PydanticMainEventType](docs/models/PydanticMainEventType.md)
 - [PyispybCoreSchemasEventsEventType](docs/models/PyispybCoreSchemasEventsEventType.md)
 - [PyispybCoreSchemasProteinComponentType](docs/models/PyispybCoreSchemasProteinComponentType.md)
 - [PyispybCoreSchemasSamplesComponentType](docs/models/PyispybCoreSchemasSamplesComponentType.md)
 - [RobotAction](docs/models/RobotAction.md)
 - [SSXCrystalCreate](docs/models/SSXCrystalCreate.md)
 - [SSXDataCollection](docs/models/SSXDataCollection.md)
 - [SSXDataCollectionCreate](docs/models/SSXDataCollectionCreate.md)
 - [SSXDataCollectionGroupCreate](docs/models/SSXDataCollectionGroupCreate.md)
 - [SSXDataCollectionProcessingCells](docs/models/SSXDataCollectionProcessingCells.md)
 - [SSXDataCollectionProcessingCellsHistogram](docs/models/SSXDataCollectionProcessingCellsHistogram.md)
 - [SSXDataCollectionProcessingCreate](docs/models/SSXDataCollectionProcessingCreate.md)
 - [SSXDataCollectionProcessingStats](docs/models/SSXDataCollectionProcessingStats.md)
 - [SSXProteinCreate](docs/models/SSXProteinCreate.md)
 - [SSXSampleComponentCreate](docs/models/SSXSampleComponentCreate.md)
 - [SSXSampleCreate](docs/models/SSXSampleCreate.md)
 - [Sample](docs/models/Sample.md)
 - [SampleContainer](docs/models/SampleContainer.md)
 - [SampleCrystal](docs/models/SampleCrystal.md)
 - [SampleImage](docs/models/SampleImage.md)
 - [SampleImageMetaData](docs/models/SampleImageMetaData.md)
 - [SampleMetaData](docs/models/SampleMetaData.md)
 - [SampleOrder](docs/models/SampleOrder.md)
 - [SampleProtein](docs/models/SampleProtein.md)
 - [SampleStatus](docs/models/SampleStatus.md)
 - [Session](docs/models/Session.md)
 - [SessionMetaData](docs/models/SessionMetaData.md)
 - [SessionResponse](docs/models/SessionResponse.md)
 - [SubSample](docs/models/SubSample.md)
 - [SubSampleMetaData](docs/models/SubSampleMetaData.md)
 - [SubSampleOrder](docs/models/SubSampleOrder.md)
 - [SubSampleSample](docs/models/SubSampleSample.md)
 - [TokenResponse](docs/models/TokenResponse.md)
 - [UIOptions](docs/models/UIOptions.md)
 - [UPLabContact](docs/models/UPLabContact.md)
 - [UPProposal](docs/models/UPProposal.md)
 - [UPProtein](docs/models/UPProtein.md)
 - [UPSession](docs/models/UPSession.md)
 - [UserPortalProposalSync](docs/models/UserPortalProposalSync.md)
 - [ValidationError](docs/models/ValidationError.md)
 - [Workflow](docs/models/Workflow.md)
 - [WorkflowStep](docs/models/WorkflowStep.md)
 - [WorkflowStepAttachment](docs/models/WorkflowStepAttachment.md)
 - [WorkflowStepMetaData](docs/models/WorkflowStepMetaData.md)
 - [XFEFluorescenceSpectrum](docs/models/XFEFluorescenceSpectrum.md)

## Documentation For Authorization

 Authentication schemes defined for the API:
## HTTPBearer

- **Type**: Bearer authentication


## Author























## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in ispyb_client.apis and ispyb_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from ispyb_client.apis.default_api import DefaultApi`
- `from ispyb_client.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import ispyb_client
from ispyb_client.apis import *
from ispyb_client.models import *
```
